@@ -10,7 +10,7 @@ use Text::Wrap 'wrap';
 use Bible::OBML::Reference;
 use Bible::OBML::HTML;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 with 'Throwable';
 
@@ -486,13 +486,33 @@ Bible::OBML - Manipulate Google/GMail Tasks
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bible-OBML.svg)](https://travis-ci.org/gryphonshafer/Bible-OBML)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bible-OBML/badge.png)](https://coveralls.io/r/gryphonshafer/Bible-OBML)
 
+=for test_synopsis my(
+    $obml_text_content, $data_structure, $skip_wrapping, $skip_smartify,
+    $content, $smart_content, $input_file, $output_file, $filename,
+);
+
 =head1 SYNOPSIS
 
+    use Bible::OBML;
+    my $self = Bible::OBML->new;
+
+    my $data_structure    = $self->parse($obml_text_content);
+    my $obml_text_content = $self->render( $data_structure, $skip_wrapping );
+
+    my $content_with_smart_quotes    = $self->smartify($content);
+    my $content_without_smart_quotes = $self->desmartify($smart_content);
+
+    $self->canonicalize( $input_file, $output_file, $skip_wrapping );
+
+    # ...and because re-inventing the wheel is fun...
+    my $file_content = $self->read_file($filename);
+    $self->write_file( $filename, $content );
+
 =head1 DESCRIPTION
 
 This module provides methods that support parsing and rendering Open Bible
@@ -575,23 +595,6 @@ arrayrefs around some number of strings. The "reference" key will always be
 a hashref with 3 keys. The structure of the values inside the arrayrefs of
 "header" and "content" can be (and usually are) nested.
 
-=for test_synopsis my( $obml_text_content, $data_structure, $skip_wrapping, $content, $smart_content );
-
-    use Bible::OBML;
-    my $self = Bible::OBML->new;
-
-    my $data_structure    = $self->parse($obml_text_content);
-    my $obml_text_content = $self->render( $data_structure, $skip_wrapping );
-
-    my $content_with_smart_quotes    = $self->smartify($content);
-    my $content_without_smart_quotes = $self->desmartify($smart_content);
-
-    $self->canonicalize( $input_file, $output_file, $skip_wrapping );
-
-    # ...and because re-inventing the wheel is fun...
-    my $file_content = $self->read_file($filename);
-    $self->write_file( $filename, $content );
-
 =head1 METHODS
 
 =head2 parse
@@ -693,7 +696,7 @@ L<Coveralls|https://coveralls.io/r/gryphonshafer/Bible-OBML>
 
 =back
 
-=for Pod::Coverage BUILD is_authed json passwd ua user
+=for Pod::Coverage BUILD
 
 =head1 AUTHOR
 
